@@ -44,9 +44,9 @@ pub(super) fn dispatch(repo: &gix::Repository, matches: &ArgMatches) -> Result<(
     let new_branchname = if let Some(name) = matches.get_one::<PartialRefName>("new-branch") {
         name
     } else {
-        let suffix = gix::actor::Time::now_local_or_utc().format(
-            time::macros::format_description!("[year][month][day]-[hour][minute][second]"),
-        );
+        let suffix = gix::date::Time::now_local_or_utc().format(time::macros::format_description!(
+            "[year][month][day]-[hour][minute][second]"
+        ));
         generated_branchname = PartialRefName::from_str(&format!("{current_branchname}-{suffix}"))
             .expect("valid partial reference name");
         &generated_branchname
